## cdist-type__package_opkg(7)

### Giel van Schijndel

`<giel+cdist--@--mortis.eu>`

## 1. NAME

cdist-type__package_opkg - Manage packages with opkg

## 2. DESCRIPTION

opkg is usually used on OpenWRT to manage packages.

## 3. REQUIRED PARAMETERS

None

## 4. OPTIONAL PARAMETERS

name
  If supplied, use the name and not the object id as the package name.
state
  Either "present" or "absent", defaults to "present"

## 5. EXAMPLES

    # Ensure lsof is installed
    __package_opkg lsof --state present

    # Remove obsolete package
    __package_opkg dnsmasq --state absent

## 6. SEE ALSO

- cdist-type(7)
- cdist-type__package(7)

## 7. COPYING

Copyright (C) 2012 Giel van Schijndel. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).